Package: arkhe
Title: Tools for Cleaning Rectangular Data
Version: 1.9.0
Authors@R: c(
    person("Nicolas", "Frerebeau", , "nicolas.frerebeau@u-bordeaux-montaigne.fr", role = c("aut", "cre"),
           comment = c(ORCID = "0000-0001-5759-4944")),
    person("Brice", "Lebrun", , "brice.lebrun@u-bordeaux-montaigne.fr", role = "ctb",
           comment = c(ORCID = "0000-0001-7503-8685", "Logo designer")),
    person("Université Bordeaux Montaigne", role = "fnd"),
    person("CNRS", role = "fnd")
  )
Maintainer: Nicolas Frerebeau <nicolas.frerebeau@u-bordeaux-montaigne.fr>
Description: A dependency-free collection of simple functions for cleaning
    rectangular data. This package allows to detect, count and replace
    values or discard rows/columns using a predicate function. In
    addition, it provides tools to check conditions and return informative
    error messages.
License: GPL (>= 3)
URL: https://packages.tesselle.org/arkhe/,
        https://github.com/tesselle/arkhe
BugReports: https://github.com/tesselle/arkhe/issues
Depends: R (>= 3.5)
Imports: methods, stats, utils
Suggests: tinytest
Encoding: UTF-8
Roxygen: list(markdown = TRUE)
RoxygenNote: 7.3.2
Collate: 'AllGenerics.R' 'append.R' 'predicates.R' 'assert.R'
        'arkhe-deprecated.R' 'arkhe-internal.R' 'arkhe-package.R'
        'assign.R' 'clean.R' 'compact.R' 'conditions.R' 'count.R'
        'describe.R' 'detect.R' 'discard.R' 'get.R' 'keep.R'
        'mathematics.R' 'remove.R' 'replace.R' 'scale.R' 'seek.R'
        'sparsity.R' 'statistics.R' 'utilities.R' 'zzz.R'
Author: Nicolas Frerebeau [aut, cre] (<https://orcid.org/0000-0001-5759-4944>),
  Brice Lebrun [ctb] (<https://orcid.org/0000-0001-7503-8685>, Logo
    designer),
  Université Bordeaux Montaigne [fnd],
  CNRS [fnd]
Built: R 4.4.2; ; 2024-12-13 02:18:58 UTC; unix
