# Generated by roxygen2: do not edit by hand

export("%+%")
export("%||%")
export(assert_colnames)
export(assert_constant)
export(assert_count)
export(assert_decreasing)
export(assert_dim)
export(assert_dimensions)
export(assert_empty)
export(assert_even)
export(assert_filled)
export(assert_function)
export(assert_greater)
export(assert_increasing)
export(assert_infinite)
export(assert_length)
export(assert_lengths)
export(assert_lower)
export(assert_missing)
export(assert_names)
export(assert_ncol)
export(assert_negative)
export(assert_nrow)
export(assert_odd)
export(assert_package)
export(assert_positive)
export(assert_rownames)
export(assert_scalar)
export(assert_square)
export(assert_symmetric)
export(assert_type)
export(assert_unique)
export(assert_whole)
export(check_class)
export(compact_cols)
export(discard_cols)
export(has_colnames)
export(has_duplicates)
export(has_infinite)
export(has_length)
export(has_missing)
export(has_names)
export(has_rownames)
export(is_atomic)
export(is_character)
export(is_constant)
export(is_decreasing)
export(is_double)
export(is_empty)
export(is_error)
export(is_even)
export(is_greater)
export(is_increasing)
export(is_integer)
export(is_list)
export(is_logical)
export(is_lower)
export(is_message)
export(is_negative)
export(is_numeric)
export(is_odd)
export(is_positive)
export(is_scalar_atomic)
export(is_scalar_character)
export(is_scalar_double)
export(is_scalar_integer)
export(is_scalar_list)
export(is_scalar_logical)
export(is_scalar_numeric)
export(is_scalar_vector)
export(is_square)
export(is_symmetric)
export(is_unique)
export(is_vector)
export(is_warning)
export(is_whole)
export(is_zero)
export(keep_cols)
export(label_percent)
export(needs)
export(scale_midpoint)
export(scale_range)
export(validate)
exportMethods(append_column)
exportMethods(append_rownames)
exportMethods(assign_colnames)
exportMethods(assign_rownames)
exportMethods(bootstrap)
exportMethods(clean_whitespace)
exportMethods(compact)
exportMethods(compact_columns)
exportMethods(compact_rows)
exportMethods(confidence_binomial)
exportMethods(confidence_mean)
exportMethods(confidence_multinomial)
exportMethods(count)
exportMethods(describe)
exportMethods(detect)
exportMethods(discard)
exportMethods(discard_columns)
exportMethods(discard_rows)
exportMethods(get_columns)
exportMethods(get_rows)
exportMethods(interval_credible)
exportMethods(interval_hdr)
exportMethods(jackknife)
exportMethods(keep)
exportMethods(keep_columns)
exportMethods(keep_rows)
exportMethods(math_gcd)
exportMethods(math_lcm)
exportMethods(remove_Inf)
exportMethods(remove_NA)
exportMethods(remove_constant)
exportMethods(remove_empty)
exportMethods(remove_zero)
exportMethods(replace_Inf)
exportMethods(replace_NA)
exportMethods(replace_empty)
exportMethods(replace_zero)
exportMethods(seek_columns)
exportMethods(seek_rows)
exportMethods(sparsity)
importFrom(methods,.valueClassTest)
importFrom(methods,setGeneric)
importFrom(methods,setMethod)
